diff -pruN 0.3.8-1/.github/workflows/autofix.yml 0.3.9-1/.github/workflows/autofix.yml
--- 0.3.8-1/.github/workflows/autofix.yml	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.9-1/.github/workflows/autofix.yml	2024-04-20 14:40:17.000000000 +0000
@@ -0,0 +1,29 @@
+name: Auto-fix
+on:
+  push:
+  pull_request:
+jobs:
+  style:
+    runs-on: ubuntu-latest
+    steps:
+      - name: Download source
+        uses: actions/checkout@v4
+      - name: Install Python
+        uses: actions/setup-python@v5
+        with:
+          python-version: '3.12'
+      - name: Install Hatch
+        run: |
+          pip install hatch
+      - name: Install dependencies
+        run: |
+          hatch run style:pip freeze
+      - name: Fix code style
+        run: |
+          hatch run style:fix --fix-only
+      - name: Check if any edits are necessary
+        run: |
+          git diff --color --exit-code
+      - name: Apply automatic fixes using pre-commit-ci-lite
+        if: failure() && github.event_name == 'pull_request'
+        uses: pre-commit-ci/lite-action@v1.0.1
diff -pruN 0.3.8-1/.github/workflows/ci.yml 0.3.9-1/.github/workflows/ci.yml
--- 0.3.8-1/.github/workflows/ci.yml	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/.github/workflows/ci.yml	2024-04-20 14:40:17.000000000 +0000
@@ -13,25 +13,27 @@ jobs:
       fail-fast: false
       matrix:
         include:
-          - python: '^3.10'
+          - python: '^3.12'
+            os: ubuntu-latest
+          - python: '3.12'
             os: macos-latest
-          - python: '3.10'
+          - python: '3.11'
             os: windows-latest
-          - python: 3.9
+          - python: '3.10'
             os: ubuntu-latest
-          - python: 3.8
+          - python: '3.9'
             os: macos-latest
-          - python: 3.7
+          - python: '3.8'
             os: windows-latest
-          - python: 3.7
+          - python: '3.8'
             os: ubuntu-latest
             versions: minimal
     runs-on: ${{matrix.os}}
     steps:
       - name: Download source
-        uses: actions/checkout@v3
+        uses: actions/checkout@v4
       - name: Install Python
-        uses: actions/setup-python@v4
+        uses: actions/setup-python@v5
         with:
           python-version: ${{matrix.python}}
       - name: Pin to lowest versions
@@ -51,11 +53,11 @@ jobs:
     runs-on: ubuntu-latest
     steps:
       - name: Download source
-        uses: actions/checkout@v3
+        uses: actions/checkout@v4
       - name: Install Python
-        uses: actions/setup-python@v4
+        uses: actions/setup-python@v5
         with:
-          python-version: '3.10'
+          python-version: '3.12'
       - name: Install Hatch
         run: |
           pip install hatch
@@ -66,12 +68,7 @@ jobs:
       - name: Check style
         if: always()
         run: |
-          hatch run style:fix
-      - name: Check formatting
-        if: always()
-        run: |
-          hatch run style:format
-          git diff --color --exit-code
+          hatch run style:check
       - name: Check types
         if: always()
         run: |
diff -pruN 0.3.8-1/.github/workflows/deploy-docs.yml 0.3.9-1/.github/workflows/deploy-docs.yml
--- 0.3.8-1/.github/workflows/deploy-docs.yml	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/.github/workflows/deploy-docs.yml	2024-04-20 14:40:17.000000000 +0000
@@ -6,22 +6,33 @@ on:
     - cron: '0 6 * * 6'
 jobs:
   build:
-    name: Deploy docs
     runs-on: ubuntu-latest
     steps:
       - name: Download source
-        uses: actions/checkout@v3
+        uses: actions/checkout@v4
       - name: Install Python
-        uses: actions/setup-python@v4
+        uses: actions/setup-python@v5
         with:
-          python-version: '3.x'
+          python-version: '3.11'
       - name: Install dependencies
-        run: pip install --no-deps -r docs/requirements.txt
+        run: pip install --no-deps -r requirements/requirements-docs.txt
       - name: Build site
-        run: mkdocs build
-      - name: Deploy to gh-pages
-        if: github.event_name == 'push' && github.ref == 'refs/heads/master'
-        uses: oprypin/push-to-gh-pages@v3
+        run: mkdocs build --strict
+      - name: Upload to GitHub Pages
+        uses: actions/upload-pages-artifact@v2
         with:
-          publish_dir: site
-          commit_message: 'Generate docs: '
+          path: site
+  deploy:
+    if: github.event_name == 'push' && github.ref_name == github.event.repository.default_branch
+    needs: build
+    permissions:
+      pages: write
+      id-token: write
+    runs-on: ubuntu-latest
+    steps:
+      - name: Deploy to GitHub Pages
+        id: deployment
+        uses: actions/deploy-pages@v2
+    environment:
+      name: github-pages
+      url: ${{ steps.deployment.outputs.page_url }}
diff -pruN 0.3.8-1/.github/workflows/deploy-release.yml 0.3.9-1/.github/workflows/deploy-release.yml
--- 0.3.8-1/.github/workflows/deploy-release.yml	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/.github/workflows/deploy-release.yml	2024-04-20 14:40:17.000000000 +0000
@@ -11,9 +11,9 @@ jobs:
     steps:
       - uses: actions/checkout@v4
       - name: Setup Python
-        uses: actions/setup-python@v4
+        uses: actions/setup-python@v5
         with:
-          python-version: '3.11'
+          python-version: '3.12'
       - name: Install dependencies
         run: pip install -U build
       - name: Build package
diff -pruN 0.3.8-1/.tools/copier-answers.yml 0.3.9-1/.tools/copier-answers.yml
--- 0.3.8-1/.tools/copier-answers.yml	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.9-1/.tools/copier-answers.yml	2024-04-20 14:40:17.000000000 +0000
@@ -0,0 +1,13 @@
+_commit: 0903da199
+_src_path: gh:oprypin/py-project-template
+copyright_date: '2020'
+mkdocs: true
+mkdocs_install_self: false
+project_description: MkDocs plugin to allow clickable sections that lead to an index page
+project_name: mkdocs-section-index
+pytest: true
+python_distribution_name: mkdocs-section-index
+python_source_path: mkdocs_section_index
+repository_name: oprypin/mkdocs-section-index
+script_test: true
+
diff -pruN 0.3.8-1/.tools/docs-dependencies.sh 0.3.9-1/.tools/docs-dependencies.sh
--- 0.3.8-1/.tools/docs-dependencies.sh	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/.tools/docs-dependencies.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh
-set -e
-
-hatch env show --json | jq -r ".docs.dependencies | .[]" | pip-compile -U - -o docs/requirements.txt
diff -pruN 0.3.8-1/.tools/release.sh 0.3.9-1/.tools/release.sh
--- 0.3.8-1/.tools/release.sh	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/.tools/release.sh	2024-04-20 14:40:17.000000000 +0000
@@ -8,7 +8,7 @@ git diff --quiet HEAD pyproject.toml
 rm -rf dist
 hatch version "$1"
 hatch build
-git add */__init__.py
+git add mkdocs_section_index/__init__.py
 git commit -m "v$1"
 git tag -a -m "" "v$1"
 git push origin master --tags
diff -pruN 0.3.8-1/.tools/test.sh 0.3.9-1/.tools/test.sh
--- 0.3.8-1/.tools/test.sh	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.9-1/.tools/test.sh	2024-04-20 14:40:17.000000000 +0000
@@ -0,0 +1,6 @@
+#!/bin/sh
+set -e
+
+cd "$(dirname "$0")/.."
+
+mkdocs build -f example/mkdocs.yml --strict
diff -pruN 0.3.8-1/README.md 0.3.9-1/README.md
--- 0.3.8-1/README.md	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/README.md	2024-04-20 14:40:17.000000000 +0000
@@ -3,7 +3,7 @@
 **[Plugin][] for [MkDocs][] to allow clickable sections that lead to an index page**
 
 [![PyPI](https://img.shields.io/pypi/v/mkdocs-section-index)](https://pypi.org/project/mkdocs-section-index/)
-[![GitHub](https://img.shields.io/github/license/oprypin/mkdocs-section-index)](https://github.com/oprypin/mkdocs-section-index/blob/master/LICENSE.md)
+[![License](https://img.shields.io/github/license/oprypin/mkdocs-section-index)](https://github.com/oprypin/mkdocs-section-index/blob/master/LICENSE.md)
 [![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/oprypin/mkdocs-section-index/ci.yml.svg)](https://github.com/oprypin/mkdocs-section-index/actions?query=event%3Apush+branch%3Amaster)
 
 ```shell
diff -pruN 0.3.8-1/debian/changelog 0.3.9-1/debian/changelog
--- 0.3.8-1/debian/changelog	2023-09-24 20:09:21.000000000 +0000
+++ 0.3.9-1/debian/changelog	2024-04-25 06:25:25.000000000 +0000
@@ -1,3 +1,10 @@
+mkdocs-section-index (0.3.9-1) unstable; urgency=medium
+
+  * New upstream release.
+  * Update copyright year.
+
+ -- Edward Betts <edward@4angle.com>  Thu, 25 Apr 2024 07:25:25 +0100
+
 mkdocs-section-index (0.3.8-1) unstable; urgency=medium
 
   * New upstream release.
diff -pruN 0.3.8-1/debian/copyright 0.3.9-1/debian/copyright
--- 0.3.8-1/debian/copyright	2023-01-31 09:33:35.000000000 +0000
+++ 0.3.9-1/debian/copyright	2024-04-25 06:25:25.000000000 +0000
@@ -8,7 +8,7 @@ Copyright: 2020 Oleh Prypin <oleh@pryp.i
 License: MIT
 
 Files: debian/*
-Copyright: 2022-2023 Edward Betts <edward@4angle.com>
+Copyright: 2022-2024 Edward Betts <edward@4angle.com>
 License: MIT
 
 
diff -pruN 0.3.8-1/docs/requirements.txt 0.3.9-1/docs/requirements.txt
--- 0.3.8-1/docs/requirements.txt	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/docs/requirements.txt	1970-01-01 00:00:00.000000000 +0000
@@ -1,55 +0,0 @@
-#
-# This file is autogenerated by pip-compile with python 3.10
-# To update, run:
-#
-#    pip-compile --output-file=docs/requirements.txt -
-#
-click==8.1.3
-    # via mkdocs
-ghp-import==2.1.0
-    # via mkdocs
-importlib-metadata==4.11.4
-    # via mkdocs
-jinja2==3.1.2
-    # via
-    #   mkdocs
-    #   mkdocs-material
-markdown==3.3.7
-    # via
-    #   mkdocs
-    #   mkdocs-material
-    #   pymdown-extensions
-markupsafe==2.1.1
-    # via jinja2
-mergedeep==1.3.4
-    # via mkdocs
-mkdocs==1.3.0
-    # via
-    #   -r -
-    #   mkdocs-material
-mkdocs-material==8.3.6
-    # via -r -
-mkdocs-material-extensions==1.0.3
-    # via mkdocs-material
-packaging==21.3
-    # via mkdocs
-pygments==2.12.0
-    # via mkdocs-material
-pymdown-extensions==9.5
-    # via mkdocs-material
-pyparsing==3.0.9
-    # via packaging
-python-dateutil==2.8.2
-    # via ghp-import
-pyyaml==6.0
-    # via
-    #   mkdocs
-    #   pyyaml-env-tag
-pyyaml-env-tag==0.1
-    # via mkdocs
-six==1.16.0
-    # via python-dateutil
-watchdog==2.1.9
-    # via mkdocs
-zipp==3.8.0
-    # via importlib-metadata
diff -pruN 0.3.8-1/mkdocs.yml 0.3.9-1/mkdocs.yml
--- 0.3.8-1/mkdocs.yml	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/mkdocs.yml	2024-04-20 14:40:17.000000000 +0000
@@ -1,4 +1,5 @@
 site_name: "mkdocs-section-index"
+site_description: "MkDocs plugin to allow clickable sections that lead to an index page"
 site_url: "https://oprypin.github.io/mkdocs-section-index"
 repo_url: "https://github.com/oprypin/mkdocs-section-index"
 edit_uri: blob/master/docs/
@@ -7,6 +8,7 @@ use_directory_urls: false
 theme:
   name: material
   features:
+    - content.action.edit
     - navigation.tabs
     - toc.integrate
   icon:
@@ -16,19 +18,30 @@ theme:
     accent: purple
 
 markdown_extensions:
+  - pymdownx.details
   - pymdownx.highlight
   - pymdownx.magiclink
+  - pymdownx.saneheaders
   - pymdownx.superfences
-  - pymdownx.details
   - pymdownx.snippets:
       check_paths: true
+      base_path:
+        - !relative $config_dir
   - admonition
   - def_list
   - toc:
       permalink: "#"
 
+validation:
+  omitted_files: warn
+  absolute_links: warn
+  nav:
+    absolute_links: ignore
+
 nav:
   - section-index: README.md
   - literate-nav: /mkdocs-literate-nav/
   - gen-files: /mkdocs-gen-files/
   - same-dir: /mkdocs-same-dir/
+  - code-validator: /mkdocs-code-validator/
+  - callouts: /markdown-callouts/
diff -pruN 0.3.8-1/mkdocs_section_index/__init__.py 0.3.9-1/mkdocs_section_index/__init__.py
--- 0.3.8-1/mkdocs_section_index/__init__.py	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/mkdocs_section_index/__init__.py	2024-04-20 14:40:17.000000000 +0000
@@ -3,7 +3,7 @@ from __future__ import annotations
 from mkdocs.structure.nav import Section
 from mkdocs.structure.pages import Page
 
-__version__ = "0.3.8"
+__version__ = "0.3.9"
 __all__ = ["SectionPage"]
 
 
@@ -13,7 +13,7 @@ class SectionPage(Section, Page):  # typ
         Section.__init__(self, title=title, children=children)
         self.is_section = self.is_page = True
 
-    active = Page.active  # type: ignore
+    active = Page.active  # type: ignore[assignment]
 
     def __repr__(self):
         result = Page.__repr__(self)
diff -pruN 0.3.8-1/mkdocs_section_index/rewrites.py 0.3.9-1/mkdocs_section_index/rewrites.py
--- 0.3.8-1/mkdocs_section_index/rewrites.py	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/mkdocs_section_index/rewrites.py	2024-04-20 14:40:17.000000000 +0000
@@ -62,13 +62,13 @@ class TemplateRewritingLoader(BaseLoader
 
 
 def _transform_mkdocs_sitemap_template(src: str) -> str | None:
-    if " in pages " not in src:
-        # The below only for versions <= 1.1.2.
-        return src.replace(
-            "{%- else %}",
-            "{%- endif %}{% if item.url %}",
-        )
-    return None
+    if " in pages " in src:
+        return None
+    # The below only for versions <= 1.1.2.
+    return src.replace(
+        "{%- else %}",
+        "{%- endif %}{% if item.url %}",
+    )
 
 
 def _transform_material_nav_item_template(src: str) -> str:
@@ -120,7 +120,10 @@ def _transform_material_tabs_item_templa
     )
 
 
-def _transform_readthedocs_base_template(src: str) -> str:
+def _transform_readthedocs_base_template(src: str) -> str | None:
+    if " if nav_item.is_page " in src:
+        return None
+    # The below only for versions < 1.6:
     repl = """\
         {% if nav_item.url %}
             <ul><li{% if nav_item == page %} class="current"{% endif %}>
diff -pruN 0.3.8-1/pyproject.toml 0.3.9-1/pyproject.toml
--- 0.3.8-1/pyproject.toml	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/pyproject.toml	2024-04-20 14:40:17.000000000 +0000
@@ -19,18 +19,18 @@ classifiers = [
     "License :: OSI Approved :: MIT License",
     "Operating System :: OS Independent",
     "Programming Language :: Python",
-    "Programming Language :: Python :: 3.7",
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
     "Programming Language :: Python :: 3.10",
     "Programming Language :: Python :: 3.11",
+    "Programming Language :: Python :: 3.12",
     "Topic :: Documentation",
     "Topic :: Software Development :: Documentation",
     "Topic :: Text Processing :: Markup :: Markdown",
     "Typing :: Typed",
 ]
 dynamic = ["version"]
-requires-python = ">=3.7"
+requires-python = ">=3.8"
 dependencies = [
     "mkdocs >=1.2",
 ]
@@ -50,6 +50,12 @@ path = "mkdocs_section_index/__init__.py
 [tool.hatch.build.targets.sdist]
 include = ["/mkdocs_section_index", "/tests"]
 
+[tool.hatch.env]
+requires = [
+    "hatch-mkdocs",
+    "hatch-pip-compile >=1.7.0",
+]
+
 [tool.hatch.envs.default.scripts]
 all = [
     "hatch run style:fix",
@@ -70,8 +76,8 @@ dependencies = [
 ]
 [tool.hatch.envs.test.scripts]
 test = [
-    "pytest -q",
-    "mkdocs build -f example/mkdocs.yml --strict",
+    "pytest -q {args}",
+    "bash .tools/test.sh {args}",
 ]
 
 [tool.hatch.envs.types]
@@ -79,61 +85,58 @@ dependencies = [
     "mypy",
 ]
 [tool.hatch.envs.types.scripts]
-check = [
-    "mypy mkdocs_section_index"
-]
+check = "mypy {args} mkdocs_section_index"
 
 [tool.hatch.envs.style]
-skip-install = true
+type = "pip-compile"
+detached = true
 dependencies = [
     "ruff",
-    "isort",
-    "black",
 ]
 [tool.hatch.envs.style.scripts]
+check = "ruff check mkdocs_section_index tests {args}"
+format = "ruff format -q mkdocs_section_index tests"
 fix = [
-    "ruff check --fix mkdocs_section_index tests",
+    "check --fix --unsafe-fixes",
     "format",
 ]
-format = [
-    "isort -q mkdocs_section_index tests",
-    "black -q mkdocs_section_index tests",
-]
 
+[tool.hatch.env.collectors.mkdocs.docs]
 [tool.hatch.envs.docs]
-detached = true
-dependencies = [
-    "mkdocs >=1.2",
-    "mkdocs-material >=7.3.6",
-]
-
-[tool.black]
-line-length = 100
-
-[tool.isort]
-profile = "black"
-line_length = 100
+type = "pip-compile"
 
 [tool.ruff]
+line-length = 100
+[tool.ruff.lint]
+preview = true
 select = [
-    "F", "W", "E", "UP", "YTT", "C4", "FA", "PIE", "T20", "RSE", "TCH", "DTZ",
-    "B002", "B003", "B005", "B007", "B009", "B012", "B013", "B014", "B015", "B018", "B020", "B021", "B023", "B026", "B033", "B034", "B905",
+    "F", "E", "W", "I", "UP", "YTT", "C4", "DTZ", "T10", "FA", "ISC", "PIE", "T20", "RSE", "TCH",
+    "N803", "N804", "N805", "N806", "N807", "N815", "N816", "N999",
+    "B002", "B003", "B005", "B007", "B008", "B009", "B010", "B011", "B012", "B013", "B014", "B015", "B016", "B017", "B018", "B020", "B021", "B022", "B023", "B025", "B026", "B029", "B030", "B031", "B032", "B033", "B034", "B035", "B905",
     "COM818",
-    "PERF101",
-    "PGH002", "PGH004", "PGH005",
-    "PLE", "PLW0120", "PLW0127",
-    "RUF001", "RUF007", "RUF010", "RUF100", "RUF200",
-    "SIM101", "SIM107", "SIM201", "SIM202", "SIM208", "SIM210", "SIM211", "SIM300", "SIM401", "SIM910",
+    "G001", "G010", "G202",
+    "Q004",
+    "RET502", "RET504",
+    "SIM101", "SIM103", "SIM105", "SIM107", "SIM118", "SIM201", "SIM202", "SIM208", "SIM210", "SIM211", "SIM212", "SIM220", "SIM221", "SIM222", "SIM223", "SIM300", "SIM401", "SIM910", "SIM911",
+    "PGH003", "PGH004", "PGH005",
+    "PLC0105", "PLC0131", "PLC0132", "PLC0205", "PLC0208", "PLC0414", "PLC2401", "PLC2403", "PLC2701", "PLC2801", "PLC3002",
+    "PLE0100", "PLE0101", "PLE0116", "PLE0117", "PLE0118", "PLE0241", "PLE0302", "PLE0307", "PLE0604", "PLE0605", "PLE0704", "PLE1132", "PLE1142", "PLE1205", "PLE1206", "PLE1300", "PLE1307", "PLE1310", "PLE1507", "PLE1700", "PLE2502", "PLE2510", "PLE2512", "PLE2513", "PLE2514", "PLE2515",
+    "PLR0124", "PLR0133", "PLR0206", "PLR0402", "PLR1701", "PLR1722", "PLR1733", "PLR1736",
+    "PLW0108", "PLW0120", "PLW0127", "PLW0129", "PLW0131", "PLW0245", "PLW0406", "PLW0602", "PLW0603", "PLW0604", "PLW0711", "PLW1501", "PLW1508", "PLW1514", "PLW2101", "PLW3301",
+    "TRY302", "TRY401",
+    "FLY002",
+    "PERF101", "PERF102", "PERF402", "PERF403",
+    "FURB105", "FURB118", "FURB131", "FURB132", "FURB148", "FURB163", "FURB167", "FURB168", "FURB169",
+    "LOG001", "LOG009",
+    "RUF001", "RUF005", "RUF007", "RUF008", "RUF009", "RUF010", "RUF013", "RUF015", "RUF016", "RUF017", "RUF018", "RUF019", "RUF020", "RUF021", "RUF022", "RUF100", "RUF200",
 ]
 ignore = ["E501", "E731"]
-[tool.ruff.flake8-comprehensions]
+[tool.ruff.lint.flake8-comprehensions]
 allow-dict-calls-with-keyword-arguments = true
 
 [tool.mypy]
-ignore_missing_imports = true
 warn_unreachable = true
-no_implicit_optional = true
-show_error_codes = true
+allow_redefinition = true
 
 [tool.pytest.ini_options]
 addopts = "--tb=native"
diff -pruN 0.3.8-1/requirements/requirements-docs.txt 0.3.9-1/requirements/requirements-docs.txt
--- 0.3.8-1/requirements/requirements-docs.txt	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.9-1/requirements/requirements-docs.txt	2024-04-20 14:40:17.000000000 +0000
@@ -0,0 +1,76 @@
+#
+# This file is autogenerated by hatch-pip-compile with Python 3.11
+#
+# - mkdocs
+# - mkdocs-material
+# - pymdown-extensions
+#
+
+babel==2.13.1
+    # via mkdocs-material
+certifi==2023.7.22
+    # via requests
+charset-normalizer==3.3.1
+    # via requests
+click==8.1.7
+    # via mkdocs
+colorama==0.4.6
+    # via mkdocs-material
+ghp-import==2.1.0
+    # via mkdocs
+idna==3.4
+    # via requests
+jinja2==3.1.2
+    # via
+    #   mkdocs
+    #   mkdocs-material
+markdown==3.5
+    # via
+    #   mkdocs
+    #   mkdocs-material
+    #   pymdown-extensions
+markupsafe==2.1.3
+    # via
+    #   jinja2
+    #   mkdocs
+mergedeep==1.3.4
+    # via mkdocs
+mkdocs==1.5.3
+    # via
+    #   -r -
+    #   mkdocs-material
+mkdocs-material==9.4.7
+    # via -r -
+mkdocs-material-extensions==1.3
+    # via mkdocs-material
+packaging==23.2
+    # via mkdocs
+paginate==0.5.6
+    # via mkdocs-material
+pathspec==0.11.2
+    # via mkdocs
+platformdirs==3.11.0
+    # via mkdocs
+pygments==2.16.1
+    # via mkdocs-material
+pymdown-extensions==10.3.1
+    # via mkdocs-material
+python-dateutil==2.8.2
+    # via ghp-import
+pyyaml==6.0.1
+    # via
+    #   mkdocs
+    #   pymdown-extensions
+    #   pyyaml-env-tag
+pyyaml-env-tag==0.1
+    # via mkdocs
+regex==2023.10.3
+    # via mkdocs-material
+requests==2.31.0
+    # via mkdocs-material
+six==1.16.0
+    # via python-dateutil
+urllib3==2.0.7
+    # via requests
+watchdog==3.0.0
+    # via mkdocs
diff -pruN 0.3.8-1/requirements/requirements-style.txt 0.3.9-1/requirements/requirements-style.txt
--- 0.3.8-1/requirements/requirements-style.txt	1970-01-01 00:00:00.000000000 +0000
+++ 0.3.9-1/requirements/requirements-style.txt	2024-04-20 14:40:17.000000000 +0000
@@ -0,0 +1,8 @@
+#
+# This file is autogenerated by hatch-pip-compile with Python 3.11
+#
+# - ruff
+#
+
+ruff==0.2.0
+    # via hatch.envs.style
diff -pruN 0.3.8-1/setup.py 0.3.9-1/setup.py
--- 0.3.8-1/setup.py	2023-09-22 12:01:49.000000000 +0000
+++ 0.3.9-1/setup.py	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-"""Installation using setup.py is not supported.
-Use `pip install .` instead."""
-
-import sys
-
-from setuptools import setup
-
-sys.exit(__doc__)
-
-# Fake reference so GitHub still considers it a real package for statistics purposes.
-setup(
-    name="mkdocs-section-index",
-)
